@@ -1,4 +1,4 @@
-import sys, event
+import event
 from dez.http.server import HTTPDaemon, HTTPResponse, RawHTTPResponse
 
 def test_dispatch(request):
@@ -38,14 +38,14 @@ def test_dispatch(request):
 def noop():
     return True
 
-def main(port):
-    httpd = HTTPDaemon("127.0.0.1", port)
+def main(**kwargs):
+    httpd = HTTPDaemon(kwargs['domain'], kwargs['port'])
     httpd.register_prefix("/index", test_dispatch)
     event.timeout(1, noop)
     event.dispatch()
 
-def profile(port):
+def profile(**kwargs):
     import hotshot
     prof = hotshot.Profile("orbited_http_test.profile")
-    prof.runcall(main, port)
+    prof.runcall(main, **kwargs)
     prof.close()
