@@ -51,9 +51,9 @@ class TestApp(object):
         if message.failure_recipients:
             frame.failure(message.failure_recipients)
 
-def main(port):
+def main(**kwargs):
     app = TestApp()
-    server = OPServer("localhost", port)
+    server = OPServer(kwargs['domain'], kwargs['port'])
     server.set_connect_cb(app.connection_opened)
     server.start()
 
